import unittest

from packagename.somemodule import MyClass

class TestMyClass(unittest.TestCase):

    def test_x(self):
        o = MyClass()
        self.assertEqual(o.x, 1)

    def test_y(self):
        o = MyClass()
        self.assertEqual(o.y, 2)

    def test_z(self):
        o = MyClass()
        self.assertEqual(o.z, 3)




class MyClass:
    '''This is the docstring for this class'''

    def __init__(self):
        # setup per-instance variables
        self.x = 1
        self.y = 2
        self.z = 3


class MySecondClass:
    '''This is the docstring for this second class'''

    def __init__(self):
        # setup per-instance variables
        self.p = 1
        self.d = 2
        self.q = 3
